@@ -548,13 +548,16 @@ class DataTransform(forms.ModelForm):
 
     parent = forms.CharField(required=False,
                                               widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-    type = forms.CharField(required=True,
+    type = forms.CharField(required=False,
                            widget=forms.TextInput(attrs={'class': 'form-control'}))
 
     def __init__(self, *args, **kwargs):
+        print('Init Data Transform')
         super(DataTransform, self).__init__(*args, **kwargs)
         try:
             if hasattr(self.instance, 'get_children') and self.instance.get_children().count() > 0:
+                print('Adding to child form node: ' + str(self.instance.get_children().count() + 1))
+
                 dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
                                                                      fk_name='parent', form=DataTransform,
                                                                      extra=self.instance.get_children().count() + 1
@@ -563,29 +566,30 @@ class DataTransform(forms.ModelForm):
                     instance=self.instance,
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
-                    initial=[{'parent': self.instance.id}]
+                    initial=[{'parent': str(self.instance.id)}]
+                )
+                self.nested_constants_form = DataConstantsTransformerInlineFormset(
+                    instance=self.instance,
+                    data=self.data if self.is_bound else None,
+                    files=self.files if self.is_bound else None
+                )
+
+                self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
+                    instance=self.instance,
+                    data=self.data if self.is_bound else None,
+                    files=self.files if self.is_bound else None
+                )
+
+                self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
+                    instance=self.instance,
+                    data=self.data if self.is_bound else None,
+                    files=self.files if self.is_bound else None
                 )
         except Exception:
             print('excpt')
 
 
-        self.nested_constants_form = DataConstantsTransformerInlineFormset(
-            instance=self.instance,
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None
-        )
 
-        self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-            instance=self.instance,
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None
-        )
-
-        self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
-            instance=self.instance,
-            data=self.data if self.is_bound else None,
-            files=self.files if self.is_bound else None
-        )
 
     def as_p(self):
         # super(self.__class__,self).as_p()
@@ -601,6 +605,7 @@ class DataTransform(forms.ModelForm):
         if hasattr(self, 'nested_data_transformer_form') and self.nested_data_transformer_form is not None:
             forms = '       -'.join([forms,self.nested_data_transformer_form.as_p()])
         return mark_safe(forms)
+
     class Meta:
         model = DataTransformer
         fields = ['id','accessory','parent','type']
@@ -612,7 +617,7 @@ class DataTransformRoot(forms.ModelForm):
                          widget=forms.HiddenInput(attrs={'class': 'form-control'}))
     accessory = forms.CharField(required=False,
                                 widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-    type = forms.CharField(required=True,
+    type = forms.CharField(required=False,
                            widget=forms.TextInput(attrs={'class': 'form-control'}))
 
 
@@ -621,6 +626,8 @@ class DataTransformRoot(forms.ModelForm):
     #     super(HardwareTypeForm, self).__init__(*args, **kwargs)
     def __init__(self, *args, **kwargs):
         super(DataTransformRoot, self).__init__(*args, **kwargs)
+        print('Adding to root form node: ' + str(self.instance.get_children().count() + 1))
+
         dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
                                                              fk_name='parent', form=DataTransform,
                                                              extra=self.instance.get_children().count() + 1
